/**
 * @jest-environment jsdom
 */

import axios from "axios";
import { TuitioClient, fetch, invalidate } from "../client";

jest.mock("axios");

test("Tuitio client authentication", async () => {
  (axios.request as jest.Mock).mockResolvedValue({
    data: {
      token: { raw: "mock-user-pass", validFrom: new Date("10/02/2023"), validUntil: new Date("11/02/2023") },
      status: "_MOCK_"
    }
  });

  const client = new TuitioClient("https://test.com/api");
  const result = await client.authenticate("user", "pass");

  expect(result.token.raw).toBe("mock-user-pass");
  expect(result.token.validFrom).toStrictEqual(new Date("10/02/2023"));
  expect(result.token.validUntil).toStrictEqual(new Date("11/02/2023"));
  expect(result.status).toBe("_MOCK_");

  const storage = fetch();
  expect(storage.userName).toBe("user");

  invalidate();
  const emptyStorage = fetch();
  expect(emptyStorage.userName).toBeNull();
});
